${ _("Salesperson:") } | ${ report.order.salesperson.person.name } % if report.order.status == status_quote: | ${ _("Expire date:") } | ${ format_date(report.order.expire_date) } % else: |  | % endif
% if report.order.client:
${ _("Client:") } | ${ report.order.client.person.name } | ${ _("Phone number:") } | ${ format_phone(report.order.client.person.phone_number) }
${ _("CPF/CNPJ:") } | ${ report.get_person_document() } | ${ _("Mobile number") } | ${ format_phone(report.order.client.person.mobile_number) }
${ _("Address:") } | ${ report.order.client.person.get_main_address().get_address_string() } | ${ _("City/State:") } | ${ report.order.client.person.get_main_address().get_details_string() }
% endif